Index: src/x87/macro-assembler-x87.h |
diff --git a/src/x87/macro-assembler-x87.h b/src/x87/macro-assembler-x87.h |
index e567496be3774a397501aa75803f681694b52579..522b479719a24b8075ac4d00b4a166d69005073b 100644 |
--- a/src/x87/macro-assembler-x87.h |
+++ b/src/x87/macro-assembler-x87.h |
@@ -255,8 +255,8 @@ class MacroAssembler: public Assembler { |
// Leave the current exit frame. Expects the return value in |
// register eax:edx (untouched) and the pointer to the first |
- // argument in register esi. |
- void LeaveExitFrame(bool save_doubles); |
+ // argument in register esi (if pop_arguments == true). |
+ void LeaveExitFrame(bool save_doubles, bool pop_arguments = true); |
// Leave the current exit frame. Expects the return value in |
// register eax (untouched). |